var searchData=
[
  ['aaxwrapper_5fgetdescription',['AAXWrapper_GetDescription',['../againaax_8cpp.html#a6a257b7e7486f4e30b723e2798630c06',1,'againaax.cpp']]],
  ['accesstransferobject_5frt',['accessTransferObject_rt',['../../vstsdk/structSteinberg_1_1Vst_1_1RTTransferT.html#a299c8f7e3c53ec225ec99bd59539a979',1,'Steinberg::Vst::RTTransferT']]],
  ['activatebus',['activateBus',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IComponent.html#a3ab7d06aaefe03da1fcd1819f1261050',1,'Steinberg::Vst::IComponent::activateBus()'],['../../vstsdk/classSteinberg_1_1Vst_1_1Component.html#af98a434f211539013a174bbe191156e3',1,'Steinberg::Vst::AudioEffect::activateBus()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#af98a434f211539013a174bbe191156e3',1,'Steinberg::Vst::SingleComponentEffect::activateBus()'],['../classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#af98a434f211539013a174bbe191156e3',1,'Steinberg::Vst::HostCheckerProcessor::activateBus()']]],
  ['activatemainiobusses',['activateMainIOBusses',['../../vstsdk/classSteinberg_1_1Vst_1_1TestBase.html#a8fda54dda5b1ff98350169bc6612317c',1,'Steinberg::Vst::TestBase']]],
  ['addaudioinput',['addAudioInput',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#acf5189a9e37c263015c22a7f81b750c8',1,'Steinberg::Vst::AudioEffect::addAudioInput()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#acf5189a9e37c263015c22a7f81b750c8',1,'Steinberg::Vst::SingleComponentEffect::addAudioInput()']]],
  ['addaudiooutput',['addAudioOutput',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#aee9f447229f5bf7247c00d39f4bb748d',1,'Steinberg::Vst::AudioEffect::addAudioOutput()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aee9f447229f5bf7247c00d39f4bb748d',1,'Steinberg::Vst::SingleComponentEffect::addAudioOutput()']]],
  ['addchange',['addChange',['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aa9a2796814321a32d6d4790b06d47d63',1,'Steinberg::Vst::ParameterChangeTransfer']]],
  ['adddependent',['addDependent',['../../base/classSteinberg_1_1IUpdateHandler.html#a7ab1193e35e93559ccb0ebc3dd1925eb',1,'Steinberg::IUpdateHandler']]],
  ['adderrormessage',['addErrorMessage',['../../vstinterfaces/classSteinberg_1_1ITestResult.html#aed6eebaa827b0aec9dc5b5e127fa7a66',1,'Steinberg::ITestResult::addErrorMessage()'],['../classSteinberg_1_1Vst_1_1Validator.html#ad2dfcd5513e88f07d6811adb5750963c',1,'Steinberg::Vst::Validator::addErrorMessage()']]],
  ['addevent',['addEvent',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IEventList.html#aa58736dbdfb425c6c8f12b2129626370',1,'Steinberg::Vst::IEventList::addEvent()'],['../../vstsdk/classSteinberg_1_1Vst_1_1EventList.html#a368f654ec650602168bd5ddab3a9105a',1,'Steinberg::Vst::EventList::addEvent()']]],
  ['addeventinput',['addEventInput',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#a98a16757564b1a077d82e2b2decc2ad8',1,'Steinberg::Vst::AudioEffect::addEventInput()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a98a16757564b1a077d82e2b2decc2ad8',1,'Steinberg::Vst::SingleComponentEffect::addEventInput()']]],
  ['addeventoutput',['addEventOutput',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#aed058baf0101b334a42e4e0f09bcfd0e',1,'Steinberg::Vst::AudioEffect::addEventOutput()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aed058baf0101b334a42e4e0f09bcfd0e',1,'Steinberg::Vst::SingleComponentEffect::addEventOutput()']]],
  ['addfeaturelog',['addFeatureLog',['../classSteinberg_1_1Vst_1_1HostCheckerController.html#a2994126983f1437424bafc780fa5919b',1,'Steinberg::Vst::HostCheckerController']]],
  ['additem',['addItem',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IContextMenu.html#ac172d5fa00b2028a352c704dd906f236',1,'Steinberg::Vst::IContextMenu']]],
  ['addivar',['addIvar',['../../vstsdk/structSteinberg_1_1ObjCClassBuilder.html#a867a597c78baf1a1b6fc18042ef12879',1,'Steinberg::ObjCClassBuilder']]],
  ['addlogevent',['addLogEvent',['../classEventLogger.html#a181b09f3964380df6a6c13669a4fe443',1,'EventLogger::addLogEvent()'],['../classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#a181b09f3964380df6a6c13669a4fe443',1,'Steinberg::Vst::HostCheckerProcessor::addLogEvent()']]],
  ['addlogeventmessage',['addLogEventMessage',['../classSteinberg_1_1Vst_1_1HostCheckerProcessor.html#aea6b5378111b9c285895333620678821',1,'Steinberg::Vst::HostCheckerProcessor']]],
  ['addmessage',['addMessage',['../../vstinterfaces/classSteinberg_1_1ITestResult.html#ad65829b0d34b7e08770e7c51e2f00f57',1,'Steinberg::ITestResult::addMessage()'],['../classSteinberg_1_1Vst_1_1Validator.html#a2c9dba5d859ca650cf20f048e13ac370',1,'Steinberg::Vst::Validator::addMessage()']]],
  ['addmethod',['addMethod',['../../vstsdk/structSteinberg_1_1ObjCClassBuilder.html#a64333672f21fc912e2f71d1e76676b88',1,'Steinberg::ObjCClassBuilder']]],
  ['addnoteexpressiontype',['addNoteExpressionType',['../../vstsdk/classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#a627417f066ae71732d720f0734cf633c',1,'Steinberg::Vst::NoteExpressionTypeContainer']]],
  ['addparameter',['addParameter',['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterContainer.html#a85fdb751a90bc332b258174367c3ae21',1,'Steinberg::Vst::ParameterContainer::addParameter(const ParameterInfo &amp;info)'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterContainer.html#ab1ea7afd1ecc429f8324b751082e4b0f',1,'Steinberg::Vst::ParameterContainer::addParameter(const TChar *title, const TChar *units=nullptr, int32 stepCount=0, ParamValue defaultValueNormalized=0., int32 flags=ParameterInfo::kCanAutomate, int32 tag=-1, UnitID unitID=kRootUnitId, const TChar *shortTitle=nullptr)'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterContainer.html#a6214dce887302e2cdc39fe332ce899a5',1,'Steinberg::Vst::ParameterContainer::addParameter(Parameter *p)'],['../classHostCheck.html#a80e7a4b3c58843955139c761c5212b82',1,'HostCheck::addParameter()']]],
  ['addparameterdata',['addParameterData',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IParameterChanges.html#ad8a5fbbc08fc082c41ad859b01247b8e',1,'Steinberg::Vst::IParameterChanges::addParameterData()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterChanges.html#aecf67b64e5c0c9880530199fa9d7cc9a',1,'Steinberg::Vst::ParameterChanges::addParameterData()']]],
  ['addpluginterfacesupported',['addPlugInterfaceSupported',['../../vstsdk/classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html#a15c7d05751b83f5db57ccb8647be63f3',1,'Steinberg::Vst::PlugInterfaceSupport']]],
  ['addpoint',['addPoint',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IParamValueQueue.html#acf78c435afe4e71b1be548aa03ef4e3a',1,'Steinberg::Vst::IParamValueQueue::addPoint()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterValueQueue.html#a81dee9d1410d226baec024a983413241',1,'Steinberg::Vst::ParameterValueQueue::addPoint()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParamChanges.html#ab7eb03e949dfdd22d46a912533d7c07d',1,'Steinberg::Vst::ParamChanges::addPoint()']]],
  ['addprocessor',['addProcessor',['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html#a35c0a5fa5367c71ed35c53737b88880c',1,'Steinberg::Vst::InterAppAudio::MidiIO']]],
  ['addprogram',['addProgram',['../../vstsdk/classSteinberg_1_1Vst_1_1ProgramList.html#abdd3a0c7d2b61659ffbb4b2867f5f4be',1,'Steinberg::Vst::ProgramList::addProgram()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html#a180996481eda89b66ef6b8729750f711',1,'Steinberg::Vst::ProgramListWithPitchNames::addProgram()']]],
  ['addprogramlist',['addProgramList',['../../vstsdk/classSteinberg_1_1Vst_1_1EditControllerEx1.html#a97c6d1b843066330ec399d1a66fe64d1',1,'Steinberg::Vst::EditControllerEx1']]],
  ['addprotocol',['addProtocol',['../../vstsdk/structSteinberg_1_1ObjCClassBuilder.html#af6b9e115a0c5bb623f99ce0d455ec32c',1,'Steinberg::ObjCClassBuilder::addProtocol(const char *name)'],['../../vstsdk/structSteinberg_1_1ObjCClassBuilder.html#ae7a89c11ef0f50756e3b096e6ea3c640',1,'Steinberg::ObjCClassBuilder::addProtocol(Protocol *proto)']]],
  ['addref',['addRef',['../../base/classSteinberg_1_1FUnknown.html#aaa3c5a2a5410d41153d7f5e3f4e0a635',1,'Steinberg::FUnknown::addRef()'],['../../base/classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFf7a30786d3fc5dff0954bd69a280ab56.html#aceeefd83ecd3c2384778ac88c22cf96b',1,'Steinberg::FUnknownImpl::ImplementsImpl&lt; BaseClass, Directly&lt; I, DirectIFs...&gt;, Indirectly&lt; IndirectIFs...&gt; &gt;::addRef()'],['../../base/structSteinberg_1_1FUnknownImpl_1_1Detail_1_1RefCounted.html#af5147c9d251c3a3609bfcbeb3629ec53',1,'Steinberg::FUnknownImpl::Detail::RefCounted::addRef()'],['../../base/structSteinberg_1_1FUnknownImpl_1_1Detail_1_1NonDestroyable.html#af5147c9d251c3a3609bfcbeb3629ec53',1,'Steinberg::FUnknownImpl::Detail::NonDestroyable::addRef()'],['../../vstsdk/exceptionSteinberg_1_1Vst_1_1StringResult.html#aceeefd83ecd3c2384778ac88c22cf96b',1,'Steinberg::Vst::StringResult::addRef()']]],
  ['addtest',['addTest',['../../vstinterfaces/classSteinberg_1_1ITestSuite.html#a6538d0c316069abeeae72d2ca4c8f4eb',1,'Steinberg::ITestSuite::addTest()'],['../classSteinberg_1_1Vst_1_1TestSuite.html#ab5cd3d6642bf98c0e011eec89e1f7eab',1,'Steinberg::Vst::TestSuite::addTest()'],['../classSteinberg_1_1Vst_1_1Validator.html#afc96923e9a5755b429017d66df8759eb',1,'Steinberg::Vst::Validator::addTest()']]],
  ['addtestsuite',['addTestSuite',['../../vstinterfaces/classSteinberg_1_1ITestSuite.html#a3a31a9ffef8734f24e4b06ab5c9f4c50',1,'Steinberg::ITestSuite::addTestSuite()'],['../classSteinberg_1_1Vst_1_1TestSuite.html#abd9ab87ff10061a0520c0116e0d92b95',1,'Steinberg::Vst::TestSuite::addTestSuite()']]],
  ['adduimessagecontroller',['addUIMessageController',['../classSteinberg_1_1Vst_1_1AGainController.html#a267a3f7fb32c318d5a887bb666f6cc98',1,'Steinberg::Vst::AGainController']]],
  ['addunit',['addUnit',['../../vstsdk/classSteinberg_1_1Vst_1_1EditControllerEx1.html#a8fbc2c8dab1b94795bcaf35473fabdfc',1,'Steinberg::Vst::EditControllerEx1']]],
  ['adelayprocessor',['ADelayProcessor',['../classSteinberg_1_1Vst_1_1ADelayProcessor.html#a714cf92be6fa9efc8e662f6d278bc3fc',1,'Steinberg::Vst::ADelayProcessor']]],
  ['adopt',['adopt',['../../base/classSteinberg_1_1IPtr.html#a7bb3f6e7f2c0de237814076dfe445742',1,'Steinberg::FUnknownPtr']]],
  ['advance',['advance',['../../vstsdk/structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html#a0a1eb92e8f90285d812b91b9031be7bd',1,'Steinberg::Vst::SampleAccurate::Parameter::advance(int32 numSamples) noexcept'],['../../vstsdk/structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html#a24114f6f1d82cd432747762041387fab',1,'Steinberg::Vst::SampleAccurate::Parameter::advance(int32 numSamples, Proc p) noexcept']]],
  ['again',['AGain',['../classSteinberg_1_1Vst_1_1AGain.html#a9b934532e4add86437421a047a3cf7fa',1,'Steinberg::Vst::AGain']]],
  ['againuimessagecontroller',['AGainUIMessageController',['../classSteinberg_1_1Vst_1_1AGainUIMessageController.html#af4837295aab77b0570d4ad4206992755',1,'Steinberg::Vst::AGainUIMessageController']]],
  ['allnotesoff',['allNotesOff',['../classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor.html#aec246739838d962211ec3124c7f26ff3',1,'Steinberg::Vst::mda::PianoProcessor']]],
  ['allocatemessage',['allocateMessage',['../../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html#aae7bbbf07353224bb0ba77a091b87d33',1,'Steinberg::Vst::AudioEffect']]],
  ['allocparameters',['allocParameters',['../classSteinberg_1_1Vst_1_1mda_1_1Processor.html#aa0717eb65af14a8ec9de39bbc5ba5037',1,'Steinberg::Vst::mda::Processor::allocParameters()'],['../classSteinberg_1_1Vst_1_1mda_1_1SampleAccurateBaseProcessor.html#a009053d0bf0fe9fb13b29fc3155e8b8c',1,'Steinberg::Vst::mda::SampleAccurateBaseProcessor::allocParameters()']]],
  ['allowallocatesize',['allowAllocateSize',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#a34e686050e3477b842a5589d171a57be',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
  ['allowqueuelistresize',['allowQueueListResize',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#ad0fba34c6a580a12c6bbd572c7951f01',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
  ['ambiencecontroller',['AmbienceController',['../classSteinberg_1_1Vst_1_1mda_1_1AmbienceController.html#a16a6af7c0cdae25064c2193b1bb611d1',1,'Steinberg::Vst::mda::AmbienceController']]],
  ['ambienceprocessor',['AmbienceProcessor',['../classSteinberg_1_1Vst_1_1mda_1_1AmbienceProcessor.html#aab98600536455a8c7c584966978ba80c',1,'Steinberg::Vst::mda::AmbienceProcessor']]],
  ['append',['append',['../../base/classSteinberg_1_1UString.html#a014ae12c2b6d6f3042855c5e411c0445',1,'Steinberg::UString']]],
  ['appendstring',['appendString',['../../vstsdk/classSteinberg_1_1Vst_1_1StringListParameter.html#a57131772fda4fd320e3d8cd7c7c981b7',1,'Steinberg::Vst::StringListParameter']]],
  ['application_3adidfinishlaunchingwithoptions_3a',['application:didFinishLaunchingWithOptions:',['../../vstsdk/interfaceVSTInterAppAudioAppDelegateBase.html#af02564ed60997f25d5140e48a12124a7',1,'VSTInterAppAudioAppDelegateBase']]],
  ['application_3ashouldrestoreapplicationstate_3a',['application:shouldRestoreApplicationState:',['../../vstsdk/interfaceVSTInterAppAudioAppDelegateBase.html#abcb1cbedc961935b6c89523a4132889b',1,'VSTInterAppAudioAppDelegateBase']]],
  ['application_3ashouldsaveapplicationstate_3a',['application:shouldSaveApplicationState:',['../../vstsdk/interfaceVSTInterAppAudioAppDelegateBase.html#a2743b0f5024f10421664ac7180dee4fc',1,'VSTInterAppAudioAppDelegateBase']]],
  ['application_3awillfinishlaunchingwithoptions_3a',['application:willFinishLaunchingWithOptions:',['../../vstsdk/interfaceVSTInterAppAudioAppDelegateBase.html#aa189d4957e1d4bbe127f14532277ecad',1,'VSTInterAppAudioAppDelegateBase']]],
  ['applicationdidbecomeactive_3a',['applicationDidBecomeActive:',['../../vstsdk/interfaceVSTInterAppAudioAppDelegateBase.html#adf97fa0e5331aac60fe36b12f941f922',1,'VSTInterAppAudioAppDelegateBase']]],
  ['applicationwillresignactive_3a',['applicationWillResignActive:',['../../vstsdk/interfaceVSTInterAppAudioAppDelegateBase.html#a793b11175139359dcbf46cea5c0c5140',1,'VSTInterAppAudioAppDelegateBase']]],
  ['assign',['assign',['../../base/classSteinberg_1_1UString.html#a498cf35dd45ceb0bf1d20ae356204161',1,'Steinberg::UString::assign(const char16 *src, int32 srcSize=-1)'],['../../base/classSteinberg_1_1UString.html#afb01c45e7e544d446309bb6f3d3c73ad',1,'Steinberg::UString::assign(const char *src, int32 srcSize=-1)']]],
  ['at',['at',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a2508c50409f050748cc7920d2fcceb0b',1,'Steinberg::Vst::PresetFile::at()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SpeakerArray.html#afef9cc041dcdf172dd2114307f5b3ae7',1,'Steinberg::Vst::SpeakerArray::at()'],['../classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1BrownNoise.html#a35ff391f83e2539c470388bd08a6f20a',1,'Steinberg::Vst::NoteExpressionSynth::BrownNoise::at()']]],
  ['attached',['attached',['../../base/classSteinberg_1_1IPlugView.html#a9fbc345c1e87f7e6210a8a49fdb96793',1,'Steinberg::IPlugView::attached()'],['../../vstsdk/classSteinberg_1_1CPluginView.html#a9dcf7c5b95b2f148d898943729d7b113',1,'Steinberg::CPluginView::attached()']]],
  ['attachedtoparent',['attachedToParent',['../../vstsdk/classSteinberg_1_1CPluginView.html#a3eb86d0326d25d46865bc0f320b74497',1,'Steinberg::CPluginView::attachedToParent()'],['../../vstsdk/classSteinberg_1_1Vst_1_1EditorView.html#a6d3d17488dd894c98e3eeaf4836739b3',1,'Steinberg::Vst::EditorView::attachedToParent()']]],
  ['audiobuffer',['AudioBuffer',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html#a53af24182f3165ed15b4f434d7088b53',1,'Steinberg::Vst::AudioBuffer']]],
  ['audiobus',['AudioBus',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBus.html#aa88e9bd8e9d969a00f0bd035a03c359f',1,'Steinberg::Vst::AudioBus']]],
  ['audiobusbuffers',['AudioBusBuffers',['../../vstinterfaces/structSteinberg_1_1Vst_1_1AudioBusBuffers.html#a9b1b17da17d0a50b82b03273caae2b8b',1,'Steinberg::Vst::AudioBusBuffers']]],
  ['audioeffect',['AudioEffect',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#a491f4bb6a5f726c520667832df4b9a14',1,'Steinberg::Vst::AudioEffect']]]
];
